@@ -2,7 +2,6 @@ package ipmanager
 
 import (
 	"encoding/binary"
-	"log"
 	"net"
 
 	"github.com/cybertec-postgresql/vip-manager/iphlpapi"
@@ -10,7 +9,7 @@ import (
 
 // configureAddress assigns virtual IP address
 func (c *BasicConfigurer) configureAddress() bool {
-	log.Printf("Configuring address %s on %s", c.getCIDR(), c.Iface.Name)
+	log.Infof("Configuring address %s on %s", c.getCIDR(), c.Iface.Name)
 	var (
 		ip          = binary.LittleEndian.Uint32(c.VIP.AsSlice())
 		mask        = binary.LittleEndian.Uint32(c.Netmask)
@@ -18,12 +17,12 @@ func (c *BasicConfigurer) configureAddress() bool {
 	)
 	iface, err := net.InterfaceByName(c.Iface.Name)
 	if err != nil {
-		log.Printf("Got error: %v", err)
+		log.Error("Failed to access interface: ", err)
 		return false
 	}
 	err = iphlpapi.AddIPAddress(ip, mask, uint32(iface.Index), &c.ntecontext, &nteinstance)
 	if err != nil {
-		log.Printf("Got error: %v", err)
+		log.Error("Failed to add address: ", err)
 		return false
 	}
 	// For now it is save to say that also working even if a
@@ -35,10 +34,10 @@ func (c *BasicConfigurer) configureAddress() bool {
 
 // deconfigureAddress drops virtual IP address
 func (c *BasicConfigurer) deconfigureAddress() bool {
-	log.Printf("Removing address %s on %s", c.getCIDR(), c.Iface.Name)
+	log.Infof("Removing address %s on %s", c.getCIDR(), c.Iface.Name)
 	err := iphlpapi.DeleteIPAddress(c.ntecontext)
 	if err != nil {
-		log.Printf("Got error: %v", err)
+		log.Errorf("Failed to remove address %s: %v", c.getCIDR(), err)
 		return false
 	}
 	return true
